@@ -1,11 +1,13 @@
 from functools import wraps
-from typing import TYPE_CHECKING, Callable, Dict, Optional, List, Any, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Type, Union
 
 if TYPE_CHECKING:
     from redis import Redis
+
     from .job import Retry
 
 from .defaults import DEFAULT_RESULT_TTL
+from .job import Callback
 from .queue import Queue
 from .utils import backend_class
 
@@ -20,15 +22,16 @@ class job:  # noqa
         timeout: Optional[int] = None,
         result_ttl: int = DEFAULT_RESULT_TTL,
         ttl: Optional[int] = None,
-        queue_class: Optional['Queue'] = None,
+        queue_class: Optional[Type['Queue']] = None,
         depends_on: Optional[List[Any]] = None,
-        at_front: Optional[bool] = None,
+        at_front: bool = False,
         meta: Optional[Dict[Any, Any]] = None,
         description: Optional[str] = None,
         failure_ttl: Optional[int] = None,
         retry: Optional['Retry'] = None,
-        on_failure: Optional[Callable[..., Any]] = None,
-        on_success: Optional[Callable[..., Any]] = None,
+        on_failure: Optional[Union[Callback, Callable[..., Any]]] = None,
+        on_success: Optional[Union[Callback, Callable[..., Any]]] = None,
+        on_stopped: Optional[Union[Callback, Callable[..., Any]]] = None,
     ):
         """A decorator that adds a ``delay`` method to the decorated function,
         which in turn creates a RQ job when called. Accepts a required
@@ -57,8 +60,12 @@ class job:  # noqa
             description (Optional[str], optional): Job description. Defaults to None.
             failure_ttl (Optional[int], optional): Failture time to live. Defaults to None.
             retry (Optional[Retry], optional): A Retry object. Defaults to None.
-            on_failure (Optional[Callable[..., Any]], optional): Callable to run on failure. Defaults to None.
-            on_success (Optional[Callable[..., Any]], optional): Callable to run on success. Defaults to None.
+            on_failure (Optional[Union[Callback, Callable[..., Any]]], optional): Callable to run on failure. Defaults
+                to None.
+            on_success (Optional[Union[Callback, Callable[..., Any]]], optional): Callable to run on success. Defaults
+                to None.
+            on_stopped (Optional[Union[Callback, Callable[..., Any]]], optional): Callable to run when stopped. Defaults
+                to None.
         """
         self.queue = queue
         self.queue_class = backend_class(self, 'queue_class', override=queue_class)
@@ -74,6 +81,7 @@ class job:  # noqa
         self.retry = retry
         self.on_success = on_success
         self.on_failure = on_failure
+        self.on_stopped = on_stopped
 
     def __call__(self, f):
         @wraps(f)
@@ -109,6 +117,7 @@ class job:  # noqa
                 retry=self.retry,
                 on_failure=self.on_failure,
                 on_success=self.on_success,
+                on_stopped=self.on_stopped,
             )
 
         f.delay = delay
